summaryrefslogtreecommitdiff
path: root/t/t4202-log.sh
diff options
context:
space:
mode:
Diffstat (limited to 't/t4202-log.sh')
-rwxr-xr-xt/t4202-log.sh30
1 files changed, 24 insertions, 6 deletions
diff --git a/t/t4202-log.sh b/t/t4202-log.sh
index 64502e2..1e952ca 100755
--- a/t/t4202-log.sh
+++ b/t/t4202-log.sh
@@ -149,6 +149,26 @@ test_expect_success 'git log --follow' '
'
+cat > expect << EOF
+804a787 sixth
+394ef78 fifth
+5d31159 fourth
+EOF
+test_expect_success 'git log --no-walk <commits> sorts by commit time' '
+ git log --no-walk --oneline 5d31159 804a787 394ef78 > actual &&
+ test_cmp expect actual
+'
+
+cat > expect << EOF
+5d31159 fourth
+804a787 sixth
+394ef78 fifth
+EOF
+test_expect_success 'git show <commits> leaves list of commits as given' '
+ git show --oneline -s 5d31159 804a787 394ef78 > actual &&
+ test_cmp expect actual
+'
+
test_expect_success 'setup case sensitivity tests' '
echo case >one &&
test_tick &&
@@ -300,11 +320,11 @@ test_expect_success 'set up more tangled history' '
'
cat > expect <<\EOF
-* Merge branch 'reach'
+* Merge commit 'reach'
|\
| \
| \
*-. \ Merge branches 'octopus-a' and 'octopus-b'
|\ \ \
* | | | seventh
| | * | octopus-b
@@ -324,14 +344,12 @@ cat > expect <<\EOF
* | | | Merge branch 'side'
|\ \ \ \
| * | | | side-2
-| | | |/
-| | |/|
+| | |_|/
| |/| |
| * | | side-1
* | | | Second
* | | | sixth
-| | |/
-| |/|
+| |_|/
|/| |
* | | fifth
* | | fourth
@@ -300,11 +320,11 @@ test_expect_success 'set up more tangled history' '
| \
| \
-*-. \ Merge branches 'octopus-a' and 'octopus-b'
+*-. \ Merge commit 'octopus-a'; commit 'octopus-b'
|\ \ \
* | | | seventh